import * as React from 'react';
import { styled } from '@mui/material/styles';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell, { tableCellClasses } from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper, { paperClasses } from '@mui/material/Paper';
import {
  Box,
  Button,
  dividerClasses,
  IconButton,
  listClasses,
  Menu,
} from '@mui/material';
import MoreVertRoundedIcon from '@mui/icons-material/MoreVertRounded';

// Styled components for customization
const StyledTableCell = styled(TableCell)(({ theme }) => ({
  [`&.${tableCellClasses.head}`]: {
    backgroundColor: ' #1565c0',
    color: theme.palette.common.white,
  },
  [`&.${tableCellClasses.body}`]: {
    fontSize: 14,
  },
}));

const StyledTableRow = styled(TableRow)(({ theme }) => ({
  '&:nth-of-type(odd)': {
    backgroundColor: theme.palette.action.hover,
  },
  '&:last-child td, &:last-child th': {
    border: 0,
  },
}));

interface Column {
  id: string;
  label: string;
  align?: 'left' | 'center' | 'right';
}

interface Row {
  [key: string]: any;
}

interface CustomTableProps {
  columns: Column[];
  rows: Row[];
  setDeleteModal: Function;
  setRowData: Function;
  setModalOpen: Function;
}

const CustomTable: React.FC<CustomTableProps> = ({
  columns,
  rows,
  setDeleteModal,
  setRowData,
  setModalOpen,
}) => {
  console.log('columnsss', columns, rows);

  const [anchorEl, setAnchorEl] = React.useState<null | HTMLElement>(null);
  const open = Boolean(anchorEl);
  const handleClick = (event: React.MouseEvent<HTMLElement>) => {
    setAnchorEl(event.currentTarget);
  };
  const handleClose = () => {
    setAnchorEl(null);
  };

  const isImage = (value: any) => {
    if (typeof value === 'string') {
      return value.startsWith('http') || value.startsWith('data:image'); // Check for URL or base64 image
    }
    return false;
  };

  return (
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 700 }} aria-label="customized table">
        <TableHead>
          <TableRow>
            {columns.map((column) => (
              <StyledTableCell key={column.id} align={column.align || 'left'}>
                {column.label}
              </StyledTableCell>
            ))}
          </TableRow>
        </TableHead>
        <TableBody>
          {rows.map((row, rowIndex) => (
            <StyledTableRow key={rowIndex}>
              {columns.map((column) => (
                <StyledTableCell key={column.id} align={column.align || 'left'}>
                  {isImage(row[column.id]) ? (
                    <img
                      src={row[column.id]}
                      alt="Row "
                      style={{
                        width: '50px',
                        height: '50px',
                        objectFit: 'cover',
                      }}
                    />
                  ) : column.id !== 'action' ? (
                    row[column.id]
                  ) : (
                    <IconButton
                      onClick={(e) => {
                        handleClick(e);
                        setRowData(row);
                      }}
                    >
                      <MoreVertRoundedIcon />
                    </IconButton>
                  )}
                </StyledTableCell>
              ))}
            </StyledTableRow>
          ))}
        </TableBody>
      </Table>
      {open && (
        <Menu
          anchorEl={anchorEl}
          id="menu"
          open={open}
          onClose={handleClose}
          onClick={handleClose}
          transformOrigin={{ horizontal: 'right', vertical: 'top' }}
          anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
          sx={{
            [`& .${listClasses.root}`]: {
              padding: '4px',
            },
            [`& .${paperClasses.root}`]: {
              padding: 0,
            },
            [`& .${dividerClasses.root}`]: {
              margin: '4px -4px',
            },
          }}
        >
          <Box
            sx={{
              display: 'flex',
              flexDirection: 'column',
              justifyContent: 'flex-start',
            }}
          >
            <Button
              variant="text"
              onClick={() => setModalOpen(true)}
              color="primary"
              sx={{
                justifyContent: 'flex-start',
                py: 0,
                textTransform: 'capitalize',
              }}
            >
              Edit
            </Button>
            <Button
              variant="text"
              onClick={() => setDeleteModal(true)}
              color="error"
              sx={{
                justifyContent: 'flex-start',
                py: 0,
                textTransform: 'capitalize',
              }}
            >
              Delete
            </Button>
          </Box>
        </Menu>
      )}
    </TableContainer>
  );
};

export default CustomTable;
