import { createSlice, createAsyncThunk, PayloadAction } from "@reduxjs/toolkit"
import axios from "axios"
import { backendHttp, apiHttp } from "../../lib/https"
import { toast } from "react-toastify"

// Define types for state
interface User {
    map(
        arg0: (
            admin: { name: string; role: string },
            index: number
        ) => { srno: number; name: string; role: string }
    ): unknown
    id: string
    email: string
}

interface Admin {
    id: string
    name: string
    role: string
}
interface AuthState {
    user: User | null
    admins: Admin[]
    isAuthenticated: boolean
    isLoading: boolean
    error: string | null
}

// Async thunk for login
export const loginUser = createAsyncThunk<
    User,
    { email: string; password: string },
    { rejectValue: string }
>("auth/login", async ({ email, password }, { rejectWithValue }) => {
    try {
        const response = await backendHttp.post("admin/login", {
            email,
            password,
        })
        localStorage.setItem("authToken", response.data?.data?.token) // Save token
        toast.success(response.data?.message)
        return response.data
    } catch (error: any) {
        return rejectWithValue(
            error.response?.data?.message || "An error occurred"
        )
    }
})

// Async thunk for register
export const registerUser = createAsyncThunk<
    User,
    { email: string; password: string },
    { rejectValue: string }
>("auth/register", async (data, { rejectWithValue }) => {
    try {
        const response = await axios.post(
            "https://health-digi.dmlabs.in/auth/register",
            data
        )
        return response.data
    } catch (error: any) {
        return rejectWithValue(
            error.response?.data?.message || "An error occurred"
        )
    }
})

export const adminList = createAsyncThunk<
    Admin[],
    void,
    { rejectValue: string }
>("/auth", async (_, { rejectWithValue }) => {
    try {
        const response = await apiHttp.get("/auth")
        console.log(response)
        return response?.data?.data?.map(
            (admin: { name: string; role: string }) => ({
                name: admin?.name,
                role: admin?.role,
            })
        )
        // console.log(response.data.data)
    } catch (error: any) {
        return rejectWithValue(
            error.response?.data?.message || "An error occurred"
        )
    }
})

const initialState: AuthState = {
    user: null,
    admins: [],
    isAuthenticated: false,
    isLoading: false,
    error: null,
}

const authSlice = createSlice({
    name: "auth",
    initialState,
    reducers: {
        logout: (state) => {
            state.user = null
            state.isAuthenticated = false
        },
    },
    extraReducers: (builder) => {
        builder
            // Login
            .addCase(loginUser.pending, (state) => {
                state.isLoading = true
                state.error = null
            })
            .addCase(
                loginUser.fulfilled,
                (state, action: PayloadAction<User>) => {
                    state.isLoading = false
                    state.isAuthenticated = true
                    state.user = action.payload
                }
            )
            .addCase(
                loginUser.rejected,
                (state, action: PayloadAction<string | undefined>) => {
                    state.isLoading = false
                    state.error = action.payload || "An error occurred"
                }
            )
            // Register
            .addCase(registerUser.pending, (state) => {
                state.isLoading = true
                state.error = null
            })
            .addCase(
                registerUser.fulfilled,
                (state, action: PayloadAction<User>) => {
                    state.isLoading = false
                    state.isAuthenticated = true
                    state.user = action.payload
                }
            )
            .addCase(
                registerUser.rejected,
                (state, action: PayloadAction<string | undefined>) => {
                    state.isLoading = false
                    state.error = action.payload || "An error occurred"
                }
            )

            // created by Jaanvi and Eknoor
            .addCase(adminList.pending, (state) => {
                state.isLoading = true
                state.error = null
            })
            .addCase(
                adminList.fulfilled,
                (state, action: PayloadAction<Admin[]>) => {
                    state.isLoading = false
                    state.admins = action.payload // ✅ Store admins correctly
                }
            )

            .addCase(
                adminList.rejected,
                (state, action: PayloadAction<string | undefined>) => {
                    state.isLoading = false
                    state.error = action.payload || "An error occurred"
                }
            )
    },
})

export const { logout } = authSlice.actions
export default authSlice.reducer
